==> tencent_cloud_chat-1.0.1.tar.gz: lib/controller/tencent_cloud_chat_controller.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:tencent_cloud_chat/chat_sdk/components/tencent_cloud_chat_contact_sdk.dart';
import 'package:tencent_cloud_chat/chat_sdk/components/tencent_cloud_chat_conversation_sdk.dart';
import 'package:tencent_cloud_chat/components/tencent_cloud_chat_components_utils.dart';
import 'package:tencent_cloud_chat/cross_platforms_adapter/tencent_cloud_chat_platform_adapter.dart';
import 'package:tencent_cloud_chat/cross_platforms_adapter/tencent_cloud_chat_screen_adapter.dart';
import 'package:tencent_cloud_chat/data/theme/color/color_base.dart';
import 'package:tencent_cloud_chat/data/theme/tencent_cloud_chat_theme.dart';
import 'package:tencent_cloud_chat/models/tencent_cloud_chat_models.dart';
import 'package:tencent_cloud_chat/tencent_cloud_chat.dart';
import 'package:tencent_cloud_chat_sdk/tencent_im_sdk_plugin.dart';
import 'package:tencent_cloud_uikit_core/tencent_cloud_uikit_core.dart';

class TencentCloudChatCoreController {
  static bool hasInitialized = false;

  /// Initializes the Tencent Cloud Chat with the given configuration.
  ///
  /// This method sets up the Tencent Cloud Chat environment, including screen adaptation,
  /// internationalization, theme configuration, component registration, and SDK initialization.
  /// It also logs in to the Tencent Cloud Chat server with the provided user ID and signature.
  ///
  /// [context]: The BuildContext for the app.
  /// [config]: The general configuration for Tencent Cloud Chat.
  /// [options]: The initial options for Tencent Cloud Chat, including user ID, user signature, and SDKAppID.
  Future<void> initUIKit({
    required BuildContext context,
    required TencentCloudChatConfig config,
    required TencentCloudChatInitOptions options,
    List<
            ({
              TencentCloudChatPlugin pluginInstance,
              Map<String, dynamic> pluginData,
              TencentCloudChatPluginNameEnum pluginName,
              TencentCloudChatPluginWidget? builder
            })>?
        plugins,
  }) async {
    if (!hasInitialized) {
      hasInitialized = true;

      // Initialize screen adapter
      TencentCloudChatScreenAdapter.init(context);

      // Initialize internationalization
      TencentCloudChatIntl().init(context);

      // Initialize theme
      TencentCloudChatTheme.init(
        context: context,
        themeModel: config.themeConfig,
        brightness: config.brightness,
      );

      // Register components to routing table
      for (final func in config.usedComponentsRegister) {
        final TencentCloudChatComponentsEnum componentName = func();
        TencentCloudChat.dataInstance.basic.addUsedComponent(componentName);
      }

      await TencentCloudChat.cache
          .init(sdkappid: options.sdkAppID, currentLotinUserId: options.userID);

      List<V2TimConversation> convList =
          TencentCloudChat.cache.getConversationListFromCache();

      if (convList.isNotEmpty) {
        TencentCloudChat.dataInstance.conversation.updateIsGetDataEnd(true);
        TencentCloudChat.dataInstance.conversation
            .buildConversationList(convList, "getConversationListFromCache");
      }

      List<String> convKey = TencentCloudChat.cache.getAllConvKey();

      if (convKey.isNotEmpty) {
        for (var i = 0; i < convKey.length; i++) {
          var keyItem = convKey[i];
          var messageList =
              TencentCloudChat.cache.getMessageListByConvKey(keyItem);
          TencentCloudChat.dataInstance.messageData.updateMessageList(
              messageList: messageList,
              userID: keyItem.contains("c2c_") ? keyItem : null,
              groupID: keyItem.contains("group_") ? keyItem : null);
        }
      }
      // Initialize Tencent Cloud Chat SDK
      await TencentCloudChat.chatSDKInstance.initSDK(
        sdkAppID: options.sdkAppID,
      );

      // Log in to Tencent Cloud Chat Server
      TencentCloudChat.logInstance.console(
        componentName: "TencentCloudChatCoreController",
        logs:
            "The uikit components currently used are ${TencentCloudChat.dataInstance.basic.usedComponents}",
      );

      if (config.userConfig != null) {
        TencentCloudChat.dataInstance.basic
            .updateUseUserOnlineStatus(config.userConfig!);
      }

      // Set the config for each components
      if (config.messageConfig != null) {
        TencentCloudChat.dataInstance.basic.messageConfig =
            config.messageConfig!;
      }

      // Login TencentCloudChat SDK
      final loginRes = await TencentCloudChat.chatSDKInstance
          .login(userID: options.userID, userSig: options.userSig);

      if (loginRes == true) {
        if (plugins != null) {
          for (var i = 0; i < plugins.length; i++) {
            final ({
              Map<String, dynamic> pluginData,
              TencentCloudChatPlugin pluginInstance,
              TencentCloudChatPluginNameEnum pluginName,
              TencentCloudChatPluginWidget? builder
            }) plugin = plugins[i];

            await plugin.pluginInstance.init(json.encode(plugin.pluginData));

            TencentCloudChat.dataInstance.basic.addPlugin(plugin);
          }
        }

        if (TencentCloudChatPlatformAdapter().isMobile) {
          TUICore.instance.getService(TUICALLKIT_SERVICE_NAME).then((value) {
            TencentCloudChat.dataInstance.basic.useCallKit = value;
          });
        }

        final result = await TencentImSDKPlugin.v2TIMManager
            .getUsersInfo(userIDList: [options.userID]);

        if (result.code == 0 && result.data != null) {
          // TencentCloudChat.dataInstance.basic.currentUser = result.data!.first;
          TencentCloudChat.dataInstance.basic
              .updateCurrentUserInfo(userFullInfo: result.data!.first);
        }

        V2TimValueCallback<String> versionRes =
            await TencentImSDKPlugin.v2TIMManager.getVersion();
        if (versionRes.code == 0) {
          TencentCloudChat.dataInstance.basic
              .updateVersion(version: versionRes.data ?? "");
        }

        await TencentCloudChatConversationSDK
            .subscribeUnreadMessageCountByFilter();

        await TencentCloudChatConversationSDK.addConversationListener();

        await TencentCloudChatContactSDK.addFriendListener();

        await TencentCloudChatContactSDK.addGroupListener();

        TencentCloudChatConversationSDK.getConversationList(seq: "0");

        TencentCloudChatContactSDK.getFriendList();

        TencentCloudChatContactSDK.getFriendApplicationList();

        TencentCloudChatContactSDK.getBlackList();

        TencentCloudChatContactSDK.getGroupList();
      }
    }
    return;
  }

  /// Toggles the brightness mode between light and dark.
  void toggleBrightnessMode({Brightness? brightness}) {
    TencentCloudChat.dataInstance.theme
        .toggleBrightnessMode(brightness: brightness);
  }

  /// Returns a ThemeData instance based on the current brightness and configuration.
  ThemeData getThemeData({
    Brightness? brightness,
    bool needTextTheme = true,
    bool needColorScheme = true,
  }) {
    return TencentCloudChat.dataInstance.theme.getThemeData(
        brightness: brightness,
        needColorScheme: needColorScheme,
        needTextTheme: needTextTheme);
  }

  /// Sets the theme colors for the specified brightness.
  void setThemeColors({
    required Brightness brightness,
    required TencentCloudChatThemeColors themeColors,
  }) {
    TencentCloudChat.dataInstance.theme
        .setThemeColors(brightness: brightness, themeColors: themeColors);
  }

  /// Sets the brightness mode
  setBrightnessMode(Brightness value) {
    TencentCloudChat.dataInstance.theme.brightness = value;
  }

  hasConversationUnreadCount() {
    return TencentCloudChat.dataInstance.conversation.totalUnreadCount > 0;
  }
}

==> tencent_cloud_chat-1.0.4.tar.gz: lib/controller/tencent_cloud_chat_controller.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:tencent_cloud_chat/chat_sdk/components/tencent_cloud_chat_contact_sdk.dart';
import 'package:tencent_cloud_chat/chat_sdk/components/tencent_cloud_chat_conversation_sdk.dart';
import 'package:tencent_cloud_chat/components/tencent_cloud_chat_components_utils.dart';
import 'package:tencent_cloud_chat/cross_platforms_adapter/tencent_cloud_chat_platform_adapter.dart';
import 'package:tencent_cloud_chat/cross_platforms_adapter/tencent_cloud_chat_screen_adapter.dart';
import 'package:tencent_cloud_chat/data/theme/color/color_base.dart';
import 'package:tencent_cloud_chat/data/theme/tencent_cloud_chat_theme.dart';
import 'package:tencent_cloud_chat/models/tencent_cloud_chat_models.dart';
import 'package:tencent_cloud_chat/tencent_cloud_chat.dart';
import 'package:tencent_cloud_chat_sdk/tencent_im_sdk_plugin.dart';
import 'package:tencent_cloud_uikit_core/tencent_cloud_uikit_core.dart';

class TencentCloudChatCoreController {
  static bool hasInitialized = false;

  /// Initializes the Tencent Cloud Chat with the given configuration.
  ///
  /// This method sets up the Tencent Cloud Chat environment, including screen adaptation,
  /// internationalization, theme configuration, component registration, and SDK initialization.
  /// It also logs in to the Tencent Cloud Chat server with the provided user ID and signature.
  ///
  /// [context]: The BuildContext for the app.
  /// [config]: The general configuration for Tencent Cloud Chat.
  /// [options]: The initial options for Tencent Cloud Chat, including user ID, user signature, and SDKAppID.
  Future<void> initUIKit({
    required BuildContext context,
    required TencentCloudChatConfig config,
    required TencentCloudChatInitOptions options,
    List<({TencentCloudChatPlugin pluginInstance, Map<String, dynamic> pluginData, TencentCloudChatPluginNameEnum pluginName, TencentCloudChatPluginWidget? builder})>? plugins,
  }) async {
    if (!hasInitialized) {
      hasInitialized = true;

      // Initialize screen adapter
      TencentCloudChatScreenAdapter.init(context);

      // Initialize internationalization
      TencentCloudChatIntl().init(context);

      // Initialize theme
      TencentCloudChatTheme.init(
        context: context,
        themeModel: config.themeConfig,
        brightness: config.brightness,
      );

      // Register components to routing table
      for (final func in config.usedComponentsRegister) {
        final TencentCloudChatComponentsEnum componentName = func();
        TencentCloudChat.dataInstance.basic.addUsedComponent(componentName);
      }

      await TencentCloudChat.cache.init(sdkappid: options.sdkAppID, currentLotinUserId: options.userID);

      List<V2TimConversation> convList = TencentCloudChat.cache.getConversationListFromCache();

      if (convList.isNotEmpty) {
        TencentCloudChat.dataInstance.conversation.updateIsGetDataEnd(true);
        TencentCloudChat.dataInstance.conversation.buildConversationList(convList, "getConversationListFromCache");
      }

      List<String> convKey = TencentCloudChat.cache.getAllConvKey();

      if (convKey.isNotEmpty) {
        for (var i = 0; i < convKey.length; i++) {
          var keyItem = convKey[i];
          var messageList = TencentCloudChat.cache.getMessageListByConvKey(keyItem);
          TencentCloudChat.dataInstance.messageData.updateMessageList(messageList: messageList, userID: keyItem.contains("c2c_") ? keyItem : null, groupID: keyItem.contains("group_") ? keyItem : null);
        }
      }
      // Initialize Tencent Cloud Chat SDK
      await TencentCloudChat.chatSDKInstance.initSDK(
        sdkAppID: options.sdkAppID,
      );

      // Log in to Tencent Cloud Chat Server
      TencentCloudChat.logInstance.console(
        componentName: "TencentCloudChatCoreController",
        logs: "The uikit components currently used are ${TencentCloudChat.dataInstance.basic.usedComponents}",
      );

      if (config.userConfig != null) {
        TencentCloudChat.dataInstance.basic.updateUseUserOnlineStatus(config.userConfig!);
      }

      // Set the config for each components
      if (config.messageConfig != null) {
        TencentCloudChat.dataInstance.basic.messageConfig = config.messageConfig!;
      }

      // Login TencentCloudChat SDK
      final loginRes = await TencentCloudChat.chatSDKInstance.login(userID: options.userID, userSig: options.userSig);

      if (loginRes == true) {
        if (plugins != null) {
          for (var i = 0; i < plugins.length; i++) {
            final ({Map<String, dynamic> pluginData, TencentCloudChatPlugin pluginInstance, TencentCloudChatPluginNameEnum pluginName, TencentCloudChatPluginWidget? builder}) plugin = plugins[i];

            await plugin.pluginInstance.init(json.encode(plugin.pluginData));

            TencentCloudChat.dataInstance.basic.addPlugin(plugin);
          }
        }

        if (TencentCloudChatPlatformAdapter().isMobile) {
          TUICore.instance.getService(TUICALLKIT_SERVICE_NAME).then((value) {
            TencentCloudChat.dataInstance.basic.useCallKit = value;
          });
        }

        final result = await TencentImSDKPlugin.v2TIMManager.getUsersInfo(userIDList: [options.userID]);

        if (result.code == 0 && result.data != null) {
          // TencentCloudChat.dataInstance.basic.currentUser = result.data!.first;
          TencentCloudChat.dataInstance.basic.updateCurrentUserInfo(userFullInfo: result.data!.first);
        }

        V2TimValueCallback<String> versionRes = await TencentImSDKPlugin.v2TIMManager.getVersion();
        if (versionRes.code == 0) {
          TencentCloudChat.dataInstance.basic.updateVersion(version: versionRes.data ?? "");
        }

        await TencentCloudChatConversationSDK.subscribeUnreadMessageCountByFilter();

        await TencentCloudChatConversationSDK.addConversationListener();

        await TencentCloudChatContactSDK.addFriendListener();

        await TencentCloudChatContactSDK.addGroupListener();

        TencentCloudChatConversationSDK.getConversationList(seq: "0");

        TencentCloudChatContactSDK.getFriendList();

        TencentCloudChatContactSDK.getFriendApplicationList();

        TencentCloudChatContactSDK.getBlackList();

        TencentCloudChatContactSDK.getGroupList();
      }
    }
    return;
  }

  /// Toggles the brightness mode between light and dark.
  void toggleBrightnessMode({Brightness? brightness}) {
    TencentCloudChat.dataInstance.theme.toggleBrightnessMode(brightness: brightness);
  }

  /// Returns a ThemeData instance based on the current brightness and configuration.
  ThemeData getThemeData({
    Brightness? brightness,
    bool needTextTheme = true,
    bool needColorScheme = true,
  }) {
    return TencentCloudChat.dataInstance.theme.getThemeData(brightness: brightness, needColorScheme: needColorScheme, needTextTheme: needTextTheme);
  }

  /// Sets the theme colors for the specified brightness.
  void setThemeColors({
    required Brightness brightness,
    required TencentCloudChatThemeColors themeColors,
  }) {
    TencentCloudChat.dataInstance.theme.setThemeColors(brightness: brightness, themeColors: themeColors);
  }

  /// Sets the brightness mode
  setBrightnessMode(Brightness value) {
    TencentCloudChat.dataInstance.theme.brightness = value;
  }

  hasConversationUnreadCount() {
    return TencentCloudChat.dataInstance.conversation.totalUnreadCount > 0;
  }
}
